@@ -3,6 +3,13 @@ from typing import Union
 
 import graphql
 
+try:
+    # graphql-core>=3.1.0,<4
+    from graphql.utilities import build_ast_schema
+except ImportError:
+    # graphql-core>=2.1.0,<3
+    from graphql.utils.build_ast_schema import build_ast_schema
+
 from . import definitions
 
 
@@ -28,7 +35,7 @@ def build_types_reference(
     # parse schema to ast obj and filter out native graphql types
     if isinstance(schema, str):
         document_ast = graphql.parse(schema)
-        schema = graphql.utilities.build_ast_schema(document_ast)
+        schema = build_ast_schema(document_ast)
 
     type_map = {
         k: v for k, v in sorted(schema.type_map.items(), key=lambda t: t[1].name)
@@ -47,25 +54,25 @@ def build_types_reference(
     for name, obj in type_map.items():
         # This is a long if-elif chain, but graphql has only 6 different
         # types in the specs, so it won't grow bigger soon
-        if graphql.is_object_type(obj):
+        if isinstance(obj, graphql.GraphQLObjectType):
             if obj != reference.query and obj != reference.mutation:
                 reference.objects.append(obj)
                 for interface in obj.interfaces:
                     implemented_by[interface.name].append(obj)
 
-        elif graphql.is_scalar_type(obj):
+        elif isinstance(obj, graphql.GraphQLScalarType):
             reference.scalars.append(obj)
 
-        elif graphql.is_interface_type(obj):
+        elif isinstance(obj, graphql.GraphQLInterfaceType):
             reference.interfaces.append(obj)
 
-        elif graphql.is_union_type(obj):
+        elif isinstance(obj, graphql.GraphQLUnionType):
             reference.unions.append(obj)
 
-        elif graphql.is_enum_type(obj):
+        elif isinstance(obj, graphql.GraphQLEnumType):
             reference.enums.append(obj)
 
-        elif graphql.is_input_object_type(obj):
+        elif isinstance(obj, graphql.GraphQLInputObjectType):
             reference.input_objects.append(obj)
 
     for interface in reference.interfaces:
